@@ -86,7 +86,7 @@ struct d_host_info
 {
   struct d_name *on_hosts;
   char* device;
-  int device_minor;
+  unsigned device_minor;
   char* disk;
   char* address;
   char* port;
@@ -120,7 +120,7 @@ struct d_resource
 
   /* these get propagated to host_info sections later. */
   char* device;
-  int device_minor;
+  unsigned device_minor;
   char* disk;
   char* meta_disk;
   char* meta_index;
