@@ -50,13 +50,13 @@
 #define DRBD_LIB_DIR "/var/lib/drbd"
 #define NODE_ID_FILE DRBD_LIB_DIR"/node_id"
 #define GIT_HASH_BYTE   20
-#define SRCVERSION_BYTE 12     /* acutally 11 and a half. */
+#define SRCVERSION_BYTE 12     /* actually 11 and a half. */
 #define SRCVERSION_PAD (GIT_HASH_BYTE - SRCVERSION_BYTE)
 #define SVN_STYLE_OD  16
 
 struct vcs_rel {
-	u32	svn_revision;
-	char	git_hash[GIT_HASH_BYTE];
+	uint32_t svn_revision;
+	char git_hash[GIT_HASH_BYTE];
 	struct {
 		unsigned major, minor, sublvl;
 	} version;
@@ -64,12 +64,12 @@ struct vcs_rel {
 };
 
 struct node_info {
-	u64	node_uuid;
+	uint64_t node_uuid;
 	struct vcs_rel rev;
 };
 
 struct node_info_od {
-	u32 magic;
+	uint32_t magic;
 	struct node_info ni;
 } __packed;
 
@@ -280,7 +280,7 @@ void warn_on_version_mismatch(void)
 
 static char *vcs_to_str(struct vcs_rel *rev)
 {
-	static char buffer[80]; // Not generic, sufficent for the purpose.
+	static char buffer[80]; // Not generic, sufficient for the purpose.
 
 	if( rev->svn_revision ) {
 		snprintf(buffer,80,"nv="U32,rev->svn_revision);
@@ -546,7 +546,7 @@ void uc_node(enum usage_count_type type)
 		ni.rev = current_vcs_rel;
 		send = 1;
 	} else {
-		// read_node_id() was successull
+		// read_node_id() was successful
 		if (!vcs_eq(&ni.rev,&current_vcs_rel)) {
 			ni.rev = current_vcs_rel;
 			update = 1;
@@ -659,8 +659,8 @@ int adm_create_md(struct d_resource* res ,const char* cmd)
 {
 	char answer[ANSWER_SIZE];
 	struct node_info ni;
-	u64 device_uuid=0;
-	u64 device_size=0;
+	uint64_t device_uuid=0;
+	uint64_t device_size=0;
 	char *req_buf;
 	int send=0;
 	char *tb;
@@ -684,7 +684,7 @@ int adm_create_md(struct d_resource* res ,const char* cmd)
 	}
 
 	if( read_node_id(&ni) && device_size && !device_uuid) {
-		get_random_bytes(&device_uuid, sizeof(u64));
+		get_random_bytes(&device_uuid, sizeof(uint64_t));
 
 		if( global_options.usage_count == UC_YES ) send = 1;
 		if( global_options.usage_count == UC_ASK ) {
@@ -707,7 +707,7 @@ int adm_create_md(struct d_resource* res ,const char* cmd)
 	}
 
 	if(!device_uuid) {
-		get_random_bytes(&device_uuid, sizeof(u64));
+		get_random_bytes(&device_uuid, sizeof(uint64_t));
 	}
 
 	if (send) {
